Exemple d'interface d'application
=================================
![category](web)
![tag](design)
![tag](angularjs)

Une application est souvent composé des même élements:

- un menu à droite (qui se reduit en mode mobile)
- une toolbar en haut composé d'un titre et de bouton
- de plusieurs visuels (qui peuvent modifier la toolbar)

Chacun de nos exemples utiliserons angular-material et comportera dans sa partie **head**

```html
<html>
    <head>
        ...
        <!-- Angular -->
        <script src="bower_components/angular/angular.min.js"></script>
        <!-- Angular Material -->
        <script src="bower_components/angular-animate/angular-animate.min.js"></script>
        <script src="bower_components/angular-aria/angular-aria.min.js"></script>
        <script src="bower_components/angular-material/angular-material.min.js"></script>
        <link rel="stylesheet" href="bower_components/angular-material/angular-material.min.css" />
        <!-- Angular FontAwesome -->
        <link rel="stylesheet" href="bower_components/font-awesome/css/font-awesome.min.css">
        <script src="bower_components/angular-fontawesome/dist/angular-fontawesome.min.js"></script>

        <!-- MyBookCustomer application -->
        <script src="app/app.js"></script>
        <script src="app/appli1.js"></script>
        <link rel="stylesheet" href="css/mycss.css" />
        ...
    </head>
    <body>
        ...
    </body>
</html>
```

Au niveau structure de fichier, nos applications auront pour structure

```
app
 |_ app
 |  |_ app.js
 |  |_ appli1.js
 |_ css
 |  |_ mycss.css
 |_ templates
 |  |_ appli1.html
 |  |_ appli2.html
 |_ index.html

```

les fichiers js et css sont communs

fichier app.js

```javascript
var app = angular.module("MyAppli", ['picardy.fontawesome',
    'ngMaterial'
]);

// add theme
app.config(function($mdThemingProvider) {
    $mdThemingProvider.theme('default')
        .primaryPalette('green')
        .accentPalette('orange')
        .warnPalette('red');
});

// add controler
app.controller('AppController', function($scope, $mdSidenav) {

    $scope.getInit = function() {
        $scope.menus = [{
            name: 'appli1',
            icon: 'cube',
            template: 'appli1.html'
        }, {
            name: 'appli2',
            icon: 'cubes',
            template: 'appli2.html'
        }];
    };
    // manage display
    $scope.openLeftMenu = function() {
        $mdSidenav('left').toggle();
    };
    $scope.showNavIcon = function() {
        return !$mdSidenav('left').isLockedOpen();
    };

    // event
    $scope.selectView = function(menu) {
        if ($mdSidenav('left').isOpen()) {
            $scope.openLeftMenu();
        };
        $scope.view = menu.name;
    };
    // init data
    $scope.getInit();
});

```

fichier appli1.js

```javascript
// add controler
app.controller('AppControllerAppliOne', function($scope) {

    var getRandomColor = function() {
        return Math.floor(Math.random() * 16777215).toString(16);
    };

    $scope.getInit = function() {
        $scope.menuapplis = [{
            name: 'param1',
            icon: 'cube'
        }, {
            name: 'param2',
            icon: 'cubes',
        }];

        $scope.employees = [{
            name: 'John',
            age: 25,
            gender: 'boy'
        }, {
            name: 'Jessie',
            age: 30,
            gender: 'girl'
        }, {
            name: 'Johanna',
            age: 28,
            gender: 'girl'
        }, {
            name: 'Joy',
            age: 15,
            gender: 'girl'
        }, {
            name: 'Mary',
            age: 28,
            gender: 'girl'
        }, {
            name: 'Peter',
            age: 95,
            gender: 'boy'
        }, {
            name: 'Sebastian',
            age: 50,
            gender: 'boy'
        }, {
            name: 'Erika',
            age: 27,
            gender: 'girl'
        }, {
            name: 'Patrick',
            age: 40,
            gender: 'boy'
        }, {
            name: 'Samantha',
            age: 60,
            gender: 'girl'
        }];

        for (var i = $scope.employees.length; i > 0; i--) {
            $scope.employees[i - 1].color = getRandomColor();
        };
    };
    $scope.deleteEmpl = function() {
        for (var i = $scope.employees.length; i > 0; i--) {
            if ($scope.employees[i - 1].selected) {
                $scope.employees.splice(i - 1, 1);
            };
        };
        return;
    };
    // init data
    $scope.getInit();
});
```

fichier mycss.css

```css
/* appli */
md-list-item .md-button {
margin-top: auto;
margin-right: 10px;
margin-bottom: auto;
margin-left: auto;
}

.to-bottom {
    position:fixed;
    bottom:10px;
    right:10px;
    z-index: 99 !important;
}

/* angular */
.main{
  padding: 20px;
}

.no-pc {
    display: none !important;
}

/* mobile-small */
 @media all and (min-width: 0) and (max-width: 960px) {
     .no-mobile {
         display: none !important;
     }
 }


```

Solution 1
----------

En vue classique

![201510271003_classic1.png](./upload/201510271003_classic1.png)

En vue mobile

![201510271003_mobile1.png](./upload/201510271003_mobile1.png)

le principale avantage est que la toolbar est toujours visible même lors de
l'appelle du menu de gauche

Le principal incovénient : la toolbar est commune à l'ensemble des controllers


fichier index.html

```html
<body ng-app="MyAppli" ng-controller="AppController" layout="column" layout-fill>
        <md-toolbar>
            <div class="md-toolbar-tools">
                <md-button ng-click="openLeftMenu()" ng-show="showNavIcon()" class="md-fab md-mini">
                    <fa name="navicon fa-lg" aria-label="nav"></fa>
                </md-button>
                <span>Test</span>
                <span flex></span>
                <!-- toolbar -->
                <!-- menu appli -->
                <md-menu md-position-mode="target-right target" ng-class="tutu">
                    <md-button class="md-mini" ng-click="$mdOpenMenu($event)">
                        <fa name="ellipsis-v fa-lg"></fa>
                    </md-button>
                    <md-menu-content>
                        <md-menu-item ng-repeat="menu in menuapplis">
                            <md-button ng-click="">
                                <fa name="{{menu.icon}}"></fa><span>{{menu.name}}</span>
                            </md-button>
                        </md-menu-item>
                    </md-menu-content>
                </md-menu>
            </div>
        </md-toolbar>
        <md-content id="main" layout="row" layout-fill>
            <md-sidenav class="md-sidenav-left" md-component-id="left" md-is-locked-open="$mdMedia('min-width: 960px')">
                <!-- view item menu-->
                <md-list>
                    <md-list-item ng-repeat="menu in menus" ng-click="selectView(menu)">
                        <div class="menu">
                            <fa name="{{menu.icon}}"></fa><span>{{menu.name}}</span>
                        </div>
                    </md-list-item>
                </md-list>
            </md-sidenav>
            <md-content id="content" layout-fill ng-switch="view">
                <div class="main" layout="column" layout-fill ng-switch-when="appli1">
                    <ng-include src="'templates/appli1.html'" ></ng-include>
                </div>
            </md-content>
        </md-content>
</body>
```

fichier appli1.html

```html
<div class="main" ng-controller="AppControllerAppliOne">
    <md-list>
        <md-list-item class="md-2-line" ng-repeat="item in employees">
            <md-button ng-click="item.selected = !item.selected" class="md-fab md-mini" style="background-color : #{{ item.color }} !important; color: white !important;">
                <fa name="{{item.selected ? 'check' : ''}}" aria-label="nav" size='large'></fa>
            </md-button>
            <div class="md-list-item-text" layout="column">
                <h3>{{ item.name }}</h3>
                <h4>{{ item.age }}</h4>
            </div>
        </md-list-item>
    </md-list>
    <md-button ng-click="deleteEmpl()" class="md-fab to-bottom md-warn" ng-show="(employees | filter:{selected: true}).length">
        <fa name="trash fa-lg" aria-label="trash"></fa>
    </md-button>
</div>


```

Solution 2
----------

En vue classique

![201510271003_classic2.png](./upload/201510271003_classic2.png)

En vue mobile

![201510271003_mobile2.png](./upload/201510271003_mobile2.png)

le principale avantage est que la toolbar est unique par application et donc plus
facilement modifiable

Le principal incovénient : le menu de gauche empiète sur la toolbar

fichier index.html

```html
<body ng-app="MyAppli" ng-controller="AppController"  layout="row" ng-switch="view">
        <md-sidenav class="md-sidenav-left" md-component-id="left" md-is-locked-open="$mdMedia('gt-sm')">
            <!-- view item menu-->
            <md-list>
                <md-list-item ng-repeat="menu in menus" ng-click="selectView(menu)">
                    <div class="menu">
                        <fa name="{{menu.icon}}"></fa><span>{{menu.name}}</span>
                    </div>
                </md-list-item>
            </md-list>
        </md-sidenav>
        <div layout-fill ng-switch-when="appli1" ng-controller="AppControllerAppliOne">
            <ng-include src="'templates/appli1.html'" layout-fill layout="column" ></ng-include>
        </div>
</body>
```

fichier appli1.html

```html
<md-toolbar >
    <div class="md-toolbar-tools">
        <md-button ng-click="openLeftMenu()" ng-show="showNavIcon()" class="md-fab md-mini">
            <fa name="navicon fa-lg" aria-label="nav"></fa>
        </md-button>
        <span>Test</span>
        <span flex></span>
        <!-- toolbar -->
        <!-- menu appli -->
        <md-menu md-position-mode="target-right target" ng-class="tutu">
            <md-button class="md-mini" ng-click="$mdOpenMenu($event)">
                <fa name="ellipsis-v fa-lg"></fa>
            </md-button>
            <md-menu-content>
                <md-menu-item ng-repeat="menu in menuapplis">
                    <md-button ng-click="">
                        <fa name="{{menu.icon}}"></fa><span>{{menu.name}}</span>
                    </md-button>
                </md-menu-item>
            </md-menu-content>
        </md-menu>
    </div>
</md-toolbar>
<md-content id="content" layout-fill>
    <div class="main" >
    <md-list>
        <md-list-item class="md-2-line" ng-repeat="item in employees">
            <md-button ng-click="item.selected = !item.selected" class="md-fab md-mini" style="background-color : #{{ item.color }} !important; color: white !important;">
                <fa name="{{item.selected ? 'check' : ''}}" aria-label="nav" size='large'></fa>
            </md-button>
            <div class="md-list-item-text" layout="column">
                <h3>{{ item.name }}</h3>
                <h4>{{ item.age }}</h4>
            </div>
        </md-list-item>
    </md-list>
    <md-button ng-click="deleteEmpl()" class="md-fab to-bottom md-warn" ng-show="(employees | filter:{selected: true}).length">
        <fa name="trash fa-lg" aria-label="trash"></fa>
    </md-button>
</div>
</md-content>```
